==> server-core-10.3.21-sources.jar: com/xebialabs/deployit/service/version/exporter/ExporterService.java <==
package com.xebialabs.deployit.service.version.exporter;


import com.xebialabs.deployit.checksum.ChecksumAlgorithmProvider;
import com.xebialabs.deployit.packager.DarPackager;
import com.xebialabs.deployit.packager.writers.ManifestXmlWriter;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Version;
import com.xebialabs.deployit.repository.RepositoryService;
import com.xebialabs.deployit.repository.WorkDir;
import com.xebialabs.overthere.local.LocalFile;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.File;

import static com.google.common.base.Preconditions.checkArgument;
import static com.google.common.base.Preconditions.checkNotNull;

@Component
public class ExporterService {

    private final RepositoryService repositoryService;
    private final ChecksumAlgorithmProvider checksumAlgorithmProvider;

    @Autowired
    public ExporterService(RepositoryService repositoryService, final ChecksumAlgorithmProvider checksumAlgorithmProvider) {
        this.repositoryService = repositoryService;
        this.checksumAlgorithmProvider = checksumAlgorithmProvider;
    }

    public LocalFile exportDar(String versionId, final WorkDir workDir) {
        checkNotNull(versionId, "id of the version to be exported is null");

        ConfigurationItem ci = repositoryService.read(versionId, workDir);
        checkArgument(ci.getType().instanceOf(Type.valueOf(Version.class)), "Expected a subtype of udm.Version for exporting but got %s", ci.getType());

        File targetDir = new File(workDir.getPath());
        DarPackager darPackager = new DarPackager(new ManifestXmlWriter(), checksumAlgorithmProvider::getMessageDigest);
        return (LocalFile) LocalFile.valueOf(darPackager.buildPackage((Version) ci, targetDir.getAbsolutePath()).getFile());
    }
}

==> server-core-23.3.4-sources.jar: com/xebialabs/deployit/service/version/exporter/ExporterService.java <==
package com.xebialabs.deployit.service.version.exporter;


import com.xebialabs.deployit.checksum.ChecksumAlgorithmProvider;
import com.xebialabs.deployit.packager.DarPackager;
import com.xebialabs.deployit.packager.writers.ManifestXmlWriter;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Version;
import com.xebialabs.deployit.repository.RepositoryService;
import com.xebialabs.deployit.repository.WorkDir;
import com.xebialabs.overthere.local.LocalFile;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.File;

import static com.xebialabs.deployit.checks.Checks.checkArgument;
import static com.xebialabs.deployit.checks.Checks.checkNotNull;

@Component
public class ExporterService {

    private final RepositoryService repositoryService;
    private final ChecksumAlgorithmProvider checksumAlgorithmProvider;

    @Autowired
    public ExporterService(RepositoryService repositoryService, final ChecksumAlgorithmProvider checksumAlgorithmProvider) {
        this.repositoryService = repositoryService;
        this.checksumAlgorithmProvider = checksumAlgorithmProvider;
    }

    public LocalFile exportDar(String versionId, final WorkDir workDir) {
        checkNotNull(versionId, "id of the version to be exported is null");

        ConfigurationItem ci = repositoryService.read(versionId, workDir);
        checkArgument(ci.getType().instanceOf(Type.valueOf(Version.class)), "Expected a subtype of udm.Version for exporting but got %s", ci.getType());

        File targetDir = new File(workDir.getPath());
        DarPackager darPackager = new DarPackager(new ManifestXmlWriter(), checksumAlgorithmProvider::getMessageDigest);
        return (LocalFile) LocalFile.valueOf(darPackager.buildPackage((Version) ci, targetDir.getAbsolutePath()).getFile());
    }
}
